#ifndef WINPR_BUILD_FLAGS_H
#define WINPR_BUILD_FLAGS_H

#define WINPR_CFLAGS "-mtune=core2 -pipe -O3 -flto -frecord-gcc-switches -Wstringop-overread -Wformat -Wformat-security -fhardened -Wno-hardened -fvisibility=hidden -fno-omit-frame-pointer -Wredundant-decls -Wimplicit-function-declaration -fvisibility=hidden "
#define WINPR_COMPILER_ID "GNU"
#define WINPR_COMPILER_VERSION "14.3.1"
#define WINPR_TARGET_ARCH "x64"
#define WINPR_BUILD_CONFIG ""
#define WINPR_BUILD_TYPE "RelWithDebInfo"

#endif /* WINPR_BUILD_FLAGS_H */
